---------------------
PatchSet 5218 
Date: 2007/08/10 00:12:56
Author: amosjeffries
Branch: docs
Tag: (none) 
Log:
Misc style updates and doxygen linking fixes.

Members: 
	doc/Programming-Guide/02_CodingConventions.dox:1.1.2.3->1.1.2.4 
	doc/Programming-Guide/07_MainLoop.dox:1.1.2.4->1.1.2.5 
	doc/Programming-Guide/Groups.dox:1.1.2.9->1.1.2.10 
	src/cbdata.cc:1.27.2.1->1.27.2.2 
	src/cbdata.h:1.1.22.2->1.1.22.3 
	src/clientStream.cc:1.11.2.3->1.11.2.4 
	src/clientStream.h:1.7.28.4->1.7.28.5 
	src/dnsserver.cc:1.9.14.5->1.9.14.6 
	src/errorpage.cc:1.46.2.1->1.46.2.2 
	src/errorpage.h:1.3.2.1->1.3.2.2 
	src/fqdncache.cc:1.19.2.1->1.19.2.2 
	src/gopher.cc:1.27.2.3->1.27.2.4 
	src/ipcache.cc:1.20.2.1->1.20.2.2 
	src/protos.h:1.82.4.1->1.82.4.2 
	src/ssl_support.cc:1.17.2.1->1.17.2.2 
	src/ssl_support.h:1.6.10.2->1.6.10.3 

Index: squid3/doc/Programming-Guide/02_CodingConventions.dox
===================================================================
RCS file: /cvsroot/squid-sf//squid3/doc/Programming-Guide/Attic/02_CodingConventions.dox,v
retrieving revision 1.1.2.3
retrieving revision 1.1.2.4
diff -u -r1.1.2.3 -r1.1.2.4
--- squid3/doc/Programming-Guide/02_CodingConventions.dox	9 Aug 2007 12:04:50 -0000	1.1.2.3
+++ squid3/doc/Programming-Guide/02_CodingConventions.dox	10 Aug 2007 00:12:56 -0000	1.1.2.4
@@ -46,13 +46,14 @@
 
 \par
 	With unconverted modules still coded in Objective-C, the task is harder.
-	In these cases two sub-groups must be defined *API and *Internal which
-	naturally individual functions, #define, etc. are grouped using the
-	\verbatim \ingroup \endverbatim tag.
+	In these cases two sub-groups must be defined *API and *Internal into
+	which naturally individual functions, variables, etc. are grouped using
+	the \verbatim \ingroup \endverbatim tag. The API group is usually a
+	sub-group of Components and the Internal is always a sub-group of the API.
 
 \par	Rule of thumb:
 	For both items, are if its referenced from elsewhere in the code or
 	defined in the .h file it should be part of the API.
-	Everythign else should be in the Internals group.
+	Everything else should be in the Internals group.
 
  */
Index: squid3/doc/Programming-Guide/07_MainLoop.dox
===================================================================
RCS file: /cvsroot/squid-sf//squid3/doc/Programming-Guide/Attic/07_MainLoop.dox,v
retrieving revision 1.1.2.4
retrieving revision 1.1.2.5
diff -u -r1.1.2.4 -r1.1.2.5
--- squid3/doc/Programming-Guide/07_MainLoop.dox	8 Aug 2007 02:41:51 -0000	1.1.2.4
+++ squid3/doc/Programming-Guide/07_MainLoop.dox	10 Aug 2007 00:12:56 -0000	1.1.2.5
@@ -126,6 +126,6 @@
 \par
 	The timeout and lifetime handlers are called for file
 	descriptors which have been idle for too long.  They are
-	further discussed in \link 08_ClientStreams.dyn Client Streams. \endlink
+	further discussed in \link ClientStreamAPI Client Streams. \endlink
 
  */
Index: squid3/doc/Programming-Guide/Groups.dox
===================================================================
RCS file: /cvsroot/squid-sf//squid3/doc/Programming-Guide/Attic/Groups.dox,v
retrieving revision 1.1.2.9
retrieving revision 1.1.2.10
diff -u -r1.1.2.9 -r1.1.2.10
--- squid3/doc/Programming-Guide/Groups.dox	9 Aug 2007 10:05:00 -0000	1.1.2.9
+++ squid3/doc/Programming-Guide/Groups.dox	10 Aug 2007 00:12:56 -0000	1.1.2.10
@@ -71,10 +71,6 @@
  */
 
 /**
- * \defgroup ServerProtocol Server Protocols
- */
-
-/**
  * \defgroup ServerProtocolHTTP HTTP
  * \ingroup ServerProtocol
  * \todo Write Documentation about HTTP
Index: squid3/src/cbdata.cc
===================================================================
RCS file: /cvsroot/squid-sf//squid3/src/cbdata.cc,v
retrieving revision 1.27.2.1
retrieving revision 1.27.2.2
diff -u -r1.27.2.1 -r1.27.2.2
--- squid3/src/cbdata.cc	9 Aug 2007 13:13:32 -0000	1.27.2.1
+++ squid3/src/cbdata.cc	10 Aug 2007 00:12:56 -0000	1.27.2.2
@@ -1,6 +1,6 @@
 
 /*
- * $Id: cbdata.cc,v 1.27.2.1 2007/08/09 13:13:32 amosjeffries Exp $
+ * $Id: cbdata.cc,v 1.27.2.2 2007/08/10 00:12:56 amosjeffries Exp $
  *
  * DEBUG: section 45    Callback Data Registry
  * ORIGINAL AUTHOR: Duane Wessels
@@ -36,8 +36,8 @@
  */
 
 /**
- \defgroup CBDATAInternal CBDATA Internals
- \ingroup CBDATA
+ \defgroup CBDATAInternal Callback Data Allocator Internals
+ \ingroup CBDATAAPI
  *
  * These routines manage a set of registered callback data pointers.
  * One of the easiest ways to make Squid coredump is to issue a
Index: squid3/src/cbdata.h
===================================================================
RCS file: /cvsroot/squid-sf//squid3/src/cbdata.h,v
retrieving revision 1.1.22.2
retrieving revision 1.1.22.3
diff -u -r1.1.22.2 -r1.1.22.3
--- squid3/src/cbdata.h	9 Aug 2007 13:24:51 -0000	1.1.22.2
+++ squid3/src/cbdata.h	10 Aug 2007 00:12:56 -0000	1.1.22.3
@@ -1,5 +1,5 @@
 /*
- * $Id: cbdata.h,v 1.1.22.2 2007/08/09 13:24:51 amosjeffries Exp $
+ * $Id: cbdata.h,v 1.1.22.3 2007/08/10 00:12:56 amosjeffries Exp $
  *
  *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
@@ -37,7 +37,8 @@
 #include "squid.h"
 
 /**
- \defgroup CBDATAAPI Callback Data Allocator
+ \defgroup CBDATAAPI Callback Data Allocator API
+ \ingroup Components
  \par
  *    Squid's extensive use of callback functions makes it very
  *    susceptible to memory access errors. To address this all callback
Index: squid3/src/clientStream.cc
===================================================================
RCS file: /cvsroot/squid-sf//squid3/src/clientStream.cc,v
retrieving revision 1.11.2.3
retrieving revision 1.11.2.4
diff -u -r1.11.2.3 -r1.11.2.4
--- squid3/src/clientStream.cc	9 Aug 2007 13:24:51 -0000	1.11.2.3
+++ squid3/src/clientStream.cc	10 Aug 2007 00:12:56 -0000	1.11.2.4
@@ -1,6 +1,6 @@
 
 /*
- * $Id: clientStream.cc,v 1.11.2.3 2007/08/09 13:24:51 amosjeffries Exp $
+ * $Id: clientStream.cc,v 1.11.2.4 2007/08/10 00:12:56 amosjeffries Exp $
  *
  * DEBUG: section 87    Client-side Stream routines.
  * AUTHOR: Robert Collins
@@ -41,6 +41,7 @@
 
 /**
  \defgroup ClientStreamInternal Client Streams Internals
+ \ingroup ClientStreamAPI
  \par
  * A client Stream is a uni directional pipe, with the usual non-blocking
  * asynchronous approach present elsewhere in squid.
@@ -174,11 +175,7 @@
     dlinkAddAfter(cbdataReference(temp), &temp->node, list->head, list);
 }
 
-/**
- \ingroup ClientStreamInternal
- *
- * Call back the next node the in chain with it's requested data.
- */
+// API
 void
 clientStreamCallback(clientStreamNode * thisObject, ClientHttpRequest * http,
                      HttpReply * rep, StoreIOBuffer replyBuffer)
@@ -195,6 +192,10 @@
 /**
  \ingroup ClientStreamInternal
  * Call the previous node in the chain to read some data
+ *
+ \param thisObject	??
+ \param http		??
+ \param readBuffer	??
  */
 void
 clientStreamRead(clientStreamNode * thisObject, ClientHttpRequest * http,
@@ -214,6 +215,9 @@
 /**
  \ingroup ClientStreamInternal
  * Detach from the stream - only allowed for terminal members
+ *
+ \param thisObject	??
+ \param http		??
  */
 void
 clientStreamDetach(clientStreamNode * thisObject, ClientHttpRequest * http)
@@ -254,6 +258,9 @@
 /**
  \ingroup ClientStreamInternal
  * Abort the stream - detach every node in the pipeline.
+ *
+ \param thisObject	??
+ \param http		??
  */
 void
 clientStreamAbort(clientStreamNode * thisObject, ClientHttpRequest * http)
@@ -272,7 +279,10 @@
 
 /**
  \ingroup ClientStreamInternal
- * Call the upstream node to find it's status 
+ * Call the upstream node to find it's status
+ *
+ \param thisObject	??
+ \param http		??
  */
 clientStream_status_t
 clientStreamStatus(clientStreamNode * thisObject, ClientHttpRequest * http)
Index: squid3/src/clientStream.h
===================================================================
RCS file: /cvsroot/squid-sf//squid3/src/clientStream.h,v
retrieving revision 1.7.28.4
retrieving revision 1.7.28.5
diff -u -r1.7.28.4 -r1.7.28.5
--- squid3/src/clientStream.h	9 Aug 2007 13:24:51 -0000	1.7.28.4
+++ squid3/src/clientStream.h	10 Aug 2007 00:12:56 -0000	1.7.28.5
@@ -1,6 +1,6 @@
 
 /*
- * $Id: clientStream.h,v 1.7.28.4 2007/08/09 13:24:51 amosjeffries Exp $
+ * $Id: clientStream.h,v 1.7.28.5 2007/08/10 00:12:56 amosjeffries Exp $
  *
  *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
@@ -38,7 +38,7 @@
 #include "RefCount.h"
 
 /**
- \defgroup ClientStreamAPI Client Streams
+ \defgroup ClientStreamAPI Client Streams API
  \ingroup Components
  \section Introduction Introduction
  \par
@@ -55,11 +55,11 @@
  *    parameters - readbuf, readlen and readoff (in the body).
  *
  \par
- *    clientStream is the basic unit for scheduling, and the clientStreamRead
- *    and clientStreamCallback calls allow for deferred scheduled activity if
+ *    clientStream is the basic unit for scheduling, and the clientStreamRead()
+ *    and clientStreamCallback() calls allow for deferred scheduled activity if
  *    desired.
  *
- \secton OperationTheory    Theory on stream operation
+ \section OperationTheory    Theory on stream operation
  \par
  \li    Something creates a pipeline. At a minimum it needs a head with a
  *      status method and a read method, and a tail with a callback method
@@ -70,8 +70,8 @@
  \par
  *    For each node going up the pipeline, the node either:
  \li             satisfies the read request, or
- \li             inserts a new node above it and calls clientStreamRead, or
- \li             calls clientStreamRead
+ \li             inserts a new node above it and calls clientStreamRead(), or
+ \li             calls clientStreamRead()
  \todo DOCS: make the above list nested.
  *
  \par
@@ -148,16 +148,17 @@
 /**
  \ingroup ClientStreamAPI
  *
+ * Call back the next node the in chain with it's requested data.
  * Return data to the next node in the stream.
  * The data may be returned immediately, or may be delayed for a later scheduling cycle.
  *
  \param thisObject	'this' reference for the client stream
  \param http		Superset of request data, being winnowed down over time. MUST NOT be NULL.
- \param reply		Not NULL on the first call back only. Ownership is passed down the pipeline.
+ \param rep		Not NULL on the first call back only. Ownership is passed down the pipeline.
  			Each node may alter the reply if appropriate.
  \param replyBuffer	- buffer, length - where and how much.
  */
-SQUIDCEXTERN void clientStreamCallback(clientStreamNode *thisObject, ClientHttpRequest *http, HttpReply *reply, StoreIOBuffer replyBuffer);
+SQUIDCEXTERN void clientStreamCallback(clientStreamNode *thisObject, ClientHttpRequest *http, HttpReply *rep, StoreIOBuffer replyBuffer);
 
 /**
  \ingroup ClientStreamAPI
@@ -204,9 +205,9 @@
  \li	stream UNPLANNED COMPLETION - upstream has completed, but not at a pre-planned location (used for keepalive checking), and will not accept further reads().
  \li	stream NONE - no special status, further reads permitted.
  *
- \param node	'this' reference for the client stream
- \param req	MUST NOT be NULL.
+ \param thisObject	'this' reference for the client stream
+ \param http		MUST NOT be NULL.
  */
-SQUIDCEXTERN clientStream_status_t clientStreamStatus(clientStreamNode *node, ClientHttpRequest *req);
+SQUIDCEXTERN clientStream_status_t clientStreamStatus(clientStreamNode *thisObject, ClientHttpRequest *http);
 
 #endif /* SQUID_CLIENTSTREAM_H */
Index: squid3/src/dnsserver.cc
===================================================================
RCS file: /cvsroot/squid-sf//squid3/src/dnsserver.cc,v
retrieving revision 1.9.14.5
retrieving revision 1.9.14.6
diff -u -r1.9.14.5 -r1.9.14.6
--- squid3/src/dnsserver.cc	9 Aug 2007 06:25:19 -0000	1.9.14.5
+++ squid3/src/dnsserver.cc	10 Aug 2007 00:12:56 -0000	1.9.14.6
@@ -1,6 +1,6 @@
 
 /*
- * $Id: dnsserver.cc,v 1.9.14.5 2007/08/09 06:25:19 amosjeffries Exp $
+ * $Id: dnsserver.cc,v 1.9.14.6 2007/08/10 00:12:56 amosjeffries Exp $
  *
  * DEBUG: section 0     DNS Resolver
  * AUTHOR: Harvest Derived
@@ -153,8 +153,8 @@
     TCP sockets bound to the loopback interface.  The functions
     in dns.cc are primarily concerned with starting and
     stopping the dnsservers.  Reading and writing to and from
-    the dnsservers occurs in the \link IPCache IP\endlink and
-    \link FQDNCache FQDN\endlink cache modules.
+    the dnsservers occurs in the \link IPCacheAPI IP\endlink and
+    \link FQDNCacheAPI FQDN\endlink cache modules.
 
  \section dnsserverInterface Command Line Interface
  \verbatim
Index: squid3/src/errorpage.cc
===================================================================
RCS file: /cvsroot/squid-sf//squid3/src/errorpage.cc,v
retrieving revision 1.46.2.1
retrieving revision 1.46.2.2
diff -u -r1.46.2.1 -r1.46.2.2
--- squid3/src/errorpage.cc	9 Aug 2007 22:46:35 -0000	1.46.2.1
+++ squid3/src/errorpage.cc	10 Aug 2007 00:12:56 -0000	1.46.2.2
@@ -1,6 +1,6 @@
 
 /*
- * $Id: errorpage.cc,v 1.46.2.1 2007/08/09 22:46:35 amosjeffries Exp $
+ * $Id: errorpage.cc,v 1.46.2.2 2007/08/10 00:12:56 amosjeffries Exp $
  *
  * DEBUG: section 4     Error Generation
  * AUTHOR: Duane Wessels
@@ -47,7 +47,7 @@
 
 /**
  \defgroup ErrorPageInternal Error Page Internals
- \ingroup ErrorPage
+ \ingroup ErrorPageAPI
  *
  \section Abstract Abstract:
  *   These routines are used to generate error messages to be
Index: squid3/src/errorpage.h
===================================================================
RCS file: /cvsroot/squid-sf//squid3/src/errorpage.h,v
retrieving revision 1.3.2.1
retrieving revision 1.3.2.2
diff -u -r1.3.2.1 -r1.3.2.2
--- squid3/src/errorpage.h	9 Aug 2007 22:46:35 -0000	1.3.2.1
+++ squid3/src/errorpage.h	10 Aug 2007 00:12:56 -0000	1.3.2.2
@@ -1,5 +1,5 @@
 /*
- * $Id: errorpage.h,v 1.3.2.1 2007/08/09 22:46:35 amosjeffries Exp $
+ * $Id: errorpage.h,v 1.3.2.2 2007/08/10 00:12:56 amosjeffries Exp $
  *
  * DEBUG: section 4     Error Generation
  * AUTHOR: Duane Wessels
@@ -40,13 +40,8 @@
 #include "cbdata.h"
 
 /**
- \defgroup ErrorPage Error Pages
- \ingroup Components
- */
-
-/**
  \defgroup ErrorPageAPI Error Pages API
- \ingroup ErrorPage
+ \ingroup Components
  \section ErrorPageStringCodes Error Page % codes for text insertion.
  *
  \verbatim
Index: squid3/src/fqdncache.cc
===================================================================
RCS file: /cvsroot/squid-sf//squid3/src/fqdncache.cc,v
retrieving revision 1.19.2.1
retrieving revision 1.19.2.2
diff -u -r1.19.2.1 -r1.19.2.2
--- squid3/src/fqdncache.cc	8 Aug 2007 09:04:10 -0000	1.19.2.1
+++ squid3/src/fqdncache.cc	10 Aug 2007 00:12:56 -0000	1.19.2.2
@@ -1,5 +1,5 @@
 /*
- * $Id: fqdncache.cc,v 1.19.2.1 2007/08/08 09:04:10 amosjeffries Exp $
+ * $Id: fqdncache.cc,v 1.19.2.2 2007/08/10 00:12:56 amosjeffries Exp $
  *
  * DEBUG: section 35    FQDN Cache
  * AUTHOR: Harvest Derived
@@ -41,13 +41,8 @@
 #include "wordlist.h"
 
 /**
- \defgroup FQDNCache FQDN Cache
- \ingroup Components
- */
-
-/**
  \defgroup FQDNCacheAPI FQDN Cache API
- \ingroup FQDNCache
+ \ingroup Components
  \section Introduction Introduction
  \par
  *  The FQDN cache is a built-in component of squid providing
@@ -56,11 +51,13 @@
  *  mechanisms that allow non-blocking access to these mappings.
  *  The FQDN cache usually doesn't block on a request except for
  *  special cases where this is desired (see below).
+ *
+ \todo FQDN Cache should have its own API *.h file.
  */
 
 /**
  \defgroup FQDNCacheInternal FQDN Cache Internals
- \ingroup FQDNCache
+ \ingroup FQDNCacheAPI
  \par
  *  Internally, the execution flow is as follows:
  *  On a miss, fqdncache_nbgethostbyaddr() checks whether a request
@@ -523,7 +520,7 @@
  * \param handler	A pointer to the function to be called when
  *			the reply from the FQDN cache
  * 			(or the DNS if the FQDN cache misses)
- * \param handlerdata	Information that is passed to the handler
+ * \param handlerData	Information that is passed to the handler
  * 			and does not affect the FQDN cache.
  */
 void
Index: squid3/src/gopher.cc
===================================================================
RCS file: /cvsroot/squid-sf//squid3/src/gopher.cc,v
retrieving revision 1.27.2.3
retrieving revision 1.27.2.4
diff -u -r1.27.2.3 -r1.27.2.4
--- squid3/src/gopher.cc	9 Aug 2007 09:12:43 -0000	1.27.2.3
+++ squid3/src/gopher.cc	10 Aug 2007 00:12:56 -0000	1.27.2.4
@@ -1,6 +1,6 @@
 
 /*
- * $Id: gopher.cc,v 1.27.2.3 2007/08/09 09:12:43 amosjeffries Exp $
+ * $Id: gopher.cc,v 1.27.2.4 2007/08/10 00:12:56 amosjeffries Exp $
  *
  * DEBUG: section 10    Gopher
  * AUTHOR: Harvest Derived
@@ -47,18 +47,8 @@
 #include "SquidTime.h"
 
 /**
- * \defgroup ServerProtocolGopher Gopher
- * \ingroup ServerProtocol
- */
-
-/**
- \defgroup ServerProtocolGopherAPI Server-Side Gopher API
- \ingroup ServerProtocolGopher
- */
-
-/**
  \defgroup ServerProtocolGopherInternal Server-Side Gopher Internals
- \ingroup ServerProtocolGopher
+ \ingroup ServerProtocolGopherAPI
  * Gopher is somewhat complex and gross because it must convert from
  * the Gopher protocol to HTTP.
  */
Index: squid3/src/protos.h
===================================================================
RCS file: /cvsroot/squid-sf//squid3/src/protos.h,v
retrieving revision 1.82.4.1
retrieving revision 1.82.4.2
diff -u -r1.82.4.1 -r1.82.4.2
--- squid3/src/protos.h	23 Jun 2007 01:43:45 -0000	1.82.4.1
+++ squid3/src/protos.h	10 Aug 2007 00:12:56 -0000	1.82.4.2
@@ -1,6 +1,6 @@
 
 /*
- * $Id: protos.h,v 1.82.4.1 2007/06/23 01:43:45 amosjeffries Exp $
+ * $Id: protos.h,v 1.82.4.2 2007/08/10 00:12:56 amosjeffries Exp $
  *
  *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
@@ -178,13 +178,39 @@
 SQUIDCEXTERN void fqdncacheAddEntryFromHosts(char *addr, wordlist * hostnames);
 
 class FwdState;
+
+/**
+ \defgroup ServerProtocolGopherAPI Server-Side Gopher API
+ \ingroup ServerProtocol
+ \todo Squid3 re-code: Gopher should have its own API header file.
+ */
+
+/// \ingroup ServerProtocolFTPAPI
 SQUIDCEXTERN void ftpStart(FwdState *);
+
+/// \ingroup ServerProtocolFTPAPI
 SQUIDCEXTERN char *ftpUrlWith2f(const HttpRequest *);
 
+/**
+ \defgroup ServerProtocolGopherAPI Server-Side Gopher API
+ \ingroup ServerProtocol
+ \todo Squid3 re-code: Gopher should have its own API header file.
+ */
+
+/// \ingroup ServerProtocolGopherAPI
 SQUIDCEXTERN void gopherStart(FwdState *);
+
+/// \ingroup ServerProtocolGopherAPI
 SQUIDCEXTERN int gopherCachable(const HttpRequest *);
 
 
+/**
+ \defgroup ServerProtocolWhoisAPI Server-Side WHOIS API
+ \ingroup ServerProtocol
+ \todo Squid3 re-code: WHOIS should have its own API header file.
+ */
+
+/// \ingroup ServerProtocolWhoisAPI
 SQUIDCEXTERN void whoisStart(FwdState *);
 
 /* http.c */
Index: squid3/src/ssl_support.cc
===================================================================
RCS file: /cvsroot/squid-sf//squid3/src/ssl_support.cc,v
retrieving revision 1.17.2.1
retrieving revision 1.17.2.2
diff -u -r1.17.2.1 -r1.17.2.2
--- squid3/src/ssl_support.cc	9 Aug 2007 10:05:00 -0000	1.17.2.1
+++ squid3/src/ssl_support.cc	10 Aug 2007 00:12:56 -0000	1.17.2.2
@@ -1,6 +1,6 @@
 
 /*
- * $Id: ssl_support.cc,v 1.17.2.1 2007/08/09 10:05:00 amosjeffries Exp $
+ * $Id: ssl_support.cc,v 1.17.2.2 2007/08/10 00:12:56 amosjeffries Exp $
  *
  * AUTHOR: Benno Rice
  * DEBUG: section 83    SSL accelerator support
@@ -38,7 +38,7 @@
 
 /**
  \defgroup ServerProtocolSSLInternal Server-Side SSL Internals
- \ingroup ServerProtocolSSL
+ \ingroup ServerProtocolSSLAPI
  */
 
 /// \ingroup ServerProtocolSSLInternal
Index: squid3/src/ssl_support.h
===================================================================
RCS file: /cvsroot/squid-sf//squid3/src/ssl_support.h,v
retrieving revision 1.6.10.2
retrieving revision 1.6.10.3
diff -u -r1.6.10.2 -r1.6.10.3
--- squid3/src/ssl_support.h	9 Aug 2007 10:05:00 -0000	1.6.10.2
+++ squid3/src/ssl_support.h	10 Aug 2007 00:12:56 -0000	1.6.10.3
@@ -1,6 +1,6 @@
 
 /*
- * $Id: ssl_support.h,v 1.6.10.2 2007/08/09 10:05:00 amosjeffries Exp $
+ * $Id: ssl_support.h,v 1.6.10.3 2007/08/10 00:12:56 amosjeffries Exp $
  *
  * AUTHOR: Benno Rice
  *
@@ -47,13 +47,8 @@
 #endif
 
 /**
- \defgroup ServerProtocolSSL SSL
- \ingroup ServerProtocol
- */
-
-/**
  \defgroup ServerProtocolSSLAPI Server-Side SSL API
- \ingroup ServerProtocolSSL
+ \ingroup ServerProtocol
  */
 
 /// \ingroup ServerProtocolSSLAPI

Index: squid3/src/ipcache.cc
===================================================================
RCS file: /cvsroot/squid-sf//squid3/src/ipcache.cc,v
retrieving revision 1.20.2.1
retrieving revision 1.20.2.2
diff -u -r1.20.2.1 -r1.20.2.2
--- squid3/src/ipcache.cc	8 Aug 2007 08:06:11 -0000	1.20.2.1
+++ squid3/src/ipcache.cc	10 Aug 2007 00:12:56 -0000	1.20.2.2
@@ -1,6 +1,6 @@
 
 /*
- * $Id: ipcache.cc,v 1.20.2.1 2007/08/08 08:06:11 amosjeffries Exp $
+ * $Id: ipcache.cc,v 1.20.2.2 2007/08/10 00:12:56 amosjeffries Exp $
  *
  * DEBUG: section 14    IP Cache
  * AUTHOR: Harvest Derived
@@ -42,13 +42,23 @@
 #include "wordlist.h"
 
 /**
  * \defgroup IPCache IP Cache
  * \ingroup Components
+ * \section Introduction Introduction
+ * \par
+ *  The IP cache is a built-in component of squid providing
+ *  Hostname to IP-Number translation functionality and managing
+ *  the involved data-structures. Efficiency concerns require
+ *  mechanisms that allow non-blocking access to these mappings.
+ *  The IP cache usually doesn't block on a request except for
+ *  special cases where this is desired (see below).
+ *
+ \todo IP Cache should have its own API *.h header file.
  */
 
 /**
  * \defgroup IPCacheInternal IP Cache Internals
- * \ingroup IPCache
+ * \ingroup IPCacheAPI
  * \todo when IP cache is provided as a class. These sub-groups will be obsolete
  *	for now they are used to seperate the public and private functions.
  *	with the private ones all being in IPCachInternal and public in IPCacheAPI
@@ -68,19 +78,6 @@
  * the ipcache_high threshold.
  */
 
-/**
- * \defgroup IPCacheAPI IP Cache API
- * \ingroup IPCache
- * \section Introduction Introduction
- * \par
- *  The IP cache is a built-in component of squid providing
- *  Hostname to IP-Number translation functionality and managing
- *  the involved data-structures. Efficiency concerns require
- *  mechanisms that allow non-blocking access to these mappings.
- *  The IP cache usually doesn't block on a request except for
- *  special cases where this is desired (see below).
- */
-
 /// \ingroup IPCacheAPI
 typedef struct _ipcache_entry ipcache_entry;
 
@@ -42,13 +42,23 @@
 
 /**
- * \defgroup IPCache IP Cache
+ * \defgroup IPCacheAPI IP Cache API
  * \ingroup Components